@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.21';
+$VERSION = '0.23';
 
 #----------------------------------------------------------------------------
 
@@ -762,7 +762,7 @@ sub _error {
     push @{$self->{errors}}, $mess;
 }
 
-q( Currently Listening To: Rainbow - "Long Live Rock 'n' Roll" from "Long Live Rock 'n' Roll" );
+q( This release is sponsored by Made In Love: Hand made gifts for your loved ones, friends or even a treat for your own home - http://madeinlove.co.uk );
 
 __END__
 
@@ -787,9 +787,9 @@ for Miss Barbell Productions, L<http://www.missbarbell.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright (C) 2007-2012 Barbie for Miss Barbell Productions
+  Copyright (C) 2007-2015 Barbie for Miss Barbell Productions
 
-  This module is free software; you can redistribute it and/or
+  This distribution is free software; you can redistribute it and/or
   modify it under the Artistic Licence v2.
 
 =cut
